# SAP BTP Reference Architecture Templates
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates#introduction)
  * [Accessing and Using the Templates](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates#accessing-and-using-the-templates)
  * [Using SAP-Specific Shapes in Diagrams](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates#using-sap-specific-shapes-in-diagrams)


Learn how to access and use SAP BTP reference architecture templates in SAP LeanIX diagrams to design and customize SAP BTP solution architecture, ensuring alignment with SAP best practices.
